| plot.treedim | R Documentation |
Plots an Euclidean minimum spanning tree from given input data.
## S3 method for class 'treedim'
plot(
x,
...,
node.col = "orange",
node.size = 5,
main = "MST plot",
legend.cord = c(-1.2, 1.1)
)
x |
An object of type "treedim"; returned from test.trajectory, compute.stats or separability |
... |
ignore |
node.col |
vector of colors for the observations in x (vertices) |
node.size |
numerical value to represent size of nodes in the plot |
main |
title for the plot |
legend.cord |
vector of the xy coordinates for the legend c(x,y) |
result plots a minimum spanning tree for input data x
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.